<?php


namespace Pinpoint\LowStockReport\Observer\Checkout;

/**
 * Class SubmitAllAfter
 * @package Pinpoint\LowStockReport\Observer\Checkout
 */
class SubmitAllAfter implements \Magento\Framework\Event\ObserverInterface
{
    /**
     * @var \Magento\CatalogInventory\Model\Spi\StockRegistryProviderInterface
     */
    protected $stockRegistryProvider;

    /**
     * @var \Pinpoint\Core\Helper\Config
     */
    protected $configHelper;

    /**
     * @var \Magento\Catalog\Api\ProductRepositoryInterface
     */
    protected $productRepository;

    /**
     * @var \Pinpoint\LowStockReport\Helper\Email
     */
    protected $emailHelper;

    /**
     * SubmitAllAfter constructor.
     * @param \Magento\CatalogInventory\Model\Spi\StockRegistryProviderInterface $stockRegistryProvider
     * @param \Pinpoint\Core\Helper\Config $configHelper
     * @param \Magento\Catalog\Api\ProductRepositoryInterface $productRepository
     * @param \Pinpoint\LowStockReport\Helper\Email $emailHelper
     */
    public function __construct(
        \Magento\CatalogInventory\Model\Spi\StockRegistryProviderInterface $stockRegistryProvider,
        \Pinpoint\Core\Helper\Config $configHelper,
        \Magento\Catalog\Api\ProductRepositoryInterface $productRepository,
        \Pinpoint\LowStockReport\Helper\Email $emailHelper
    ) {
        $this->stockRegistryProvider = $stockRegistryProvider;
        $this->configHelper = $configHelper;
        $this->productRepository = $productRepository;
        $this->emailHelper = $emailHelper;
    }

    /**
     * Execute observer
     *
     * @param \Magento\Framework\Event\Observer $observer
     * @return void
     */
    public function execute (
        \Magento\Framework\Event\Observer $observer
    ) {
        /** @var \Magento\Sales\Model\Order\Interceptor $order */
        $order = $observer->getOrder();
        /** @var \Magento\Quote\Model\Quote $quote */
        $quote = $observer->getQuote();

        /** @var \Magento\Quote\Model\Quote\Item $item */
        foreach ($quote->getAllItems() as $item) {
            $product = $this->productRepository->getById($item->getProduct()->getId());
            if ($stockAlert = $product->getCustomAttribute('stock_alert_qty')) {
                $stockItem = $this->stockRegistryProvider->getStockItem($item->getProduct()->getId(), $order->getStoreId());
                if ($stockItem->getQty() <= $stockAlert->getValue()) {
                    $email = null;
                    if ($contactEmail = $product->getCustomAttribute('stock_alert_email')) {
                        $email = $contactEmail->getValue();
                    } else {
                        $email = $this->configHelper->getConfigValue('pinpoint_lowstockreport/emails/contact_email');
                    }

                    if ($email) {
                        $emailData = [
                            'data' => [
                                'itemname' => $item->getName(),
                                'stocklevel' => $stockItem->getQty(),
                                'threshold' => $stockAlert->getValue()
                            ],
                            'sender' => [
                                'name' => $order->getStore()->getFrontendName(),
                                'email' => $this->configHelper->getConfigValue('trans_email/ident_sales/email')
                            ],
                            'recipient' => [
                                'name' => 'Stock Notification',
                                'email' => $email
                            ]
                        ];

                        $this->emailHelper->sendLowStockNotification(
                            $emailData['data'],
                            $emailData['sender'],
                            $emailData['recipient']
                        );
                    }
                }
            }
        }
    }
}
